---
title: pcg_anno
---

Helper functions for adding annotations to neurons generated by pcg_skel.

::: pcg_skel.pcg_anno
    options:
        show_source: false
        heading_level: 2
        members_order: "source"
        filters:
            - "!^_"
            - "^__"
